% Clear all existing variables from the workspace.
clear;
clc;

LonMean = 127.2604444444444;
LonStd  = 0.174222222222213;
LatMean = 35.891611111111111;
LatStd  = 0.382111111111115;
HeiMean = 332;
HeiStd  = 536;

% ========================================
%       Measure Train Accuracy
% ========================================
% Load the data set. 
DBTrainSample = load('TrainDBData2.dat');
X_train = DBTrainSample(:, 1:2);
Y_train = DBTrainSample(:, 3);

inputDim1 = length(X_train(1,:));
% Set 'm' to the number of data points.
m1 = size(X_train, 1);

TP = load('TrainingParameter.mat');

% For each training sample...
yfit = zeros(m1, 1);
for i = 1 : m1
    % Compute the scores for both categories.
    % For Regression
    scores = evaluateFuncApproxRBFN(TP.Centers, TP.betas, TP.Theta, 1, X_train(i, :));
    yfit(i) = scores;
end

Lon_train = (X_train(:,1)*LonStd/2.0) + LonMean;
Lat_train = (X_train(:,2)*LatStd/2.0) + LatMean;
Hei_train = (Y_train(:,1)*HeiStd/2.0) + HeiMean;
Hei_trainfit   = (yfit*HeiStd/2.0) + HeiMean;

ELMErr_train = mean(abs((Hei_trainfit - Hei_train)./Hei_train * 100));
TrainingAccuracy = 100 - ELMErr_train;
fprintf('Train error = %f%%, Train accuracy: %f%%\n', ELMErr_train, TrainingAccuracy);

figure(1)
plot(Lon_train, Hei_train, 'Linewidth', 1.5); hold on;
plot(Lon_train, Hei_trainfit, 'Linewidth', 1.5); hold off;
grid on;
xlabel('Longitude(Degree)')
ylabel('Height(Degree)')
legend('True DEM', 'Trained DEM by CIW-ELM')

figure(2)
plot(Lat_train, Hei_train, 'Linewidth', 1.5); hold on;
plot(Lat_train, Hei_trainfit, 'Linewidth', 1.5); hold off;
grid on;
xlabel('Latitude(Degree)')
ylabel('Height(Degree)')
legend('True DEM', 'Trained DEM by CIW-ELM')

% ========================================
%       Measure Test Accuracy
% ========================================
DBTestSample = load('TestDBData2.dat');
X_test = DBTestSample(:, 1:2);
Y_test = DBTestSample(:, 3);

% Set 'm2' to the number of data points.
m2 = size(X_test, 1);
% For each training sample...
tic;
yfit_test = zeros(m2, 1);
for i = 1 : m2
    % For Regression
    scores = evaluateFuncApproxRBFN(TP.Centers, TP.betas, TP.Theta, 1, X_test(i, :));

    yfit_test(i) = scores;

end
Evaluation_time   = toc/m2;
TestTime = Evaluation_time;

Lon_test = (X_test(:,1)*LonStd/2.0) + LonMean;
Lat_test = (X_test(:,2)*LatStd/2.0) + LatMean;
Hei_test = (Y_test(:,1)*HeiStd/2.0) + HeiMean;
Hei_testfit   = (yfit_test*HeiStd/2.0) + HeiMean;
ELMErr_test = mean(abs((Hei_testfit - Hei_test)./Hei_test * 100));
TestAcuuracy = 100 - ELMErr_test;
fprintf('Test error = %f%%, Test accuracy: %f%%\n', ELMErr_test, TestAcuuracy);
